@@ -1,7 +1,7 @@
 package Log::ger::Format::Flogger;
 
-our $DATE = '2017-06-25'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2017-08-01'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 use strict;
 use warnings;
@@ -35,7 +35,7 @@ Log::ger::Format::Flogger - Use String::Flogger for formatting instead of sprint
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -50,11 +50,7 @@ After that:
  log_debug [ 'and we can defer evaluation of %s if we want', sub { 'stuff' } ];
  log_trace sub { 'while avoiding sprintfiness, if needed' };
 
-To install only for current package:
-
- use Log::ger::Format;
- Log::ger::Format->set_for_current_package('Flogger');
- use Log::ger;
+Note that this affects the importing package only.
 
 =head1 DESCRIPTION
 
